/* ----------------------------------------------------------------------------
 *
 * Raima Database Manager
 *
 * Copyright (c) 2011 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Birdstep LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 *
 * ----------------------------------------------------------------------------
 */

/** \file cpp-exception.h
 *  \brief Header for C++ exceptions
 */

#if !defined(CPP_EXCEPTION_H_INCLUDED_)
#define CPP_EXCEPTION_H_INCLUDED_

#if !defined(__cplusplus)
#error cpp-exception.h is only for C++ applications.  Do not include it in C applications
#endif

#if defined(RDM_WINDOWS)
#pragma warning(disable : 4290)
#endif

#include "psptypes.h"
#include "rdmretcodetypes.h"
#include <exception>

namespace RDM_CPP {
    class rdm_exception;
}

#if defined(RDM_WINDOWS)
#pragma warning(disable : 4275)
#endif

/*! \brief the rdm_exception class
  This class implements the exception thrown by the RDM CPP API
  */
class RDM_PUBLIC_CLASS RDM_CPP::rdm_exception : public std::exception
{
  public:
    //! rdm_exception constructor
    rdm_exception (RDM_RETCODE error);

    //! method to get a text description of the error causing the exception to be thrown
    virtual const char *GetDescription () const throw ();
    virtual const char *GetEnum () const throw ();

    //! method to get the RDM error number
    RDM_RETCODE GetErrorCode (void) const;

  protected:
    RDM_RETCODE m_error;
};

#endif /* CPP_EXCEPTION_H_INCLUDED_ */
